import { Emitter } from 'monaco-editor';
export class MonacoGraphQLAPI {
    constructor({ languageId, schemas, modeConfiguration, formattingOptions, diagnosticSettings, }) {
        this._onDidChange = new Emitter();
        this._schemas = null;
        this._schemasById = Object.create(null);
        this._externalFragmentDefinitions = null;
        this._languageId = languageId;
        if (schemas) {
            this.setSchemaConfig(schemas);
        }
        this.setModeConfiguration(modeConfiguration);
        this.setFormattingOptions(formattingOptions);
        this.setDiagnosticSettings(diagnosticSettings);
    }
    get onDidChange() {
        return this._onDidChange.event;
    }
    get languageId() {
        return this._languageId;
    }
    get modeConfiguration() {
        return this._modeConfiguration;
    }
    get schemas() {
        return this._schemas;
    }
    schemasById() {
        return this._schemasById;
    }
    get formattingOptions() {
        return this._formattingOptions;
    }
    get diagnosticSettings() {
        return this._diagnosticSettings;
    }
    get externalFragmentDefinitions() {
        return this._externalFragmentDefinitions;
    }
    setSchemaConfig(schemas) {
        this._schemas = schemas || null;
        this._schemasById = schemas.reduce((result, schema) => {
            result[schema.uri] = schema;
            return result;
        }, Object.create(null));
        this._onDidChange.fire(this);
    }
    setExternalFragmentDefinitions(externalFragmentDefinitions) {
        this._externalFragmentDefinitions = externalFragmentDefinitions;
    }
    setModeConfiguration(modeConfiguration) {
        this._modeConfiguration = modeConfiguration || Object.create(null);
        this._onDidChange.fire(this);
    }
    setFormattingOptions(formattingOptions) {
        this._formattingOptions = formattingOptions || Object.create(null);
        this._onDidChange.fire(this);
    }
    setDiagnosticSettings(diagnosticSettings) {
        this._diagnosticSettings = diagnosticSettings || Object.create(null);
        this._onDidChange.fire(this);
    }
}
export function create(languageId, config) {
    if (!config) {
        return new MonacoGraphQLAPI({
            languageId,
            formattingOptions: formattingDefaults,
            modeConfiguration: modeConfigurationDefault,
            diagnosticSettings: diagnosticSettingDefault,
        });
    }
    else {
        const { schemas, formattingOptions, modeConfiguration, diagnosticSettings, } = config;
        return new MonacoGraphQLAPI({
            languageId,
            schemas,
            formattingOptions: {
                ...formattingDefaults,
                ...formattingOptions,
                prettierConfig: {
                    ...formattingDefaults.prettierConfig,
                    ...formattingOptions?.prettierConfig,
                },
            },
            modeConfiguration: {
                ...modeConfigurationDefault,
                ...modeConfiguration,
            },
            diagnosticSettings: {
                ...diagnosticSettingDefault,
                ...diagnosticSettings,
            },
        });
    }
}
export const modeConfigurationDefault = {
    documentFormattingEdits: true,
    documentRangeFormattingEdits: false,
    completionItems: true,
    hovers: true,
    documentSymbols: false,
    tokens: false,
    colors: false,
    foldingRanges: false,
    diagnostics: true,
    selectionRanges: false,
};
export const formattingDefaults = {
    prettierConfig: {
        tabWidth: 2,
    },
};
export const diagnosticSettingDefault = {
    jsonDiagnosticSettings: {
        schemaValidation: 'error',
    },
};
//# sourceMappingURL=api.js.map